==> kleopatra_16.04.2.orig.tar.xz: kleopatra-16.04.2/src/kwatchgnupg/kwatchgnupgconfig.h <==
/*
    kwatchgnupgconfig.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2001,2002,2004,2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef KWATCHGNUPGCONFIG_H
#define KWATCHGNUPGCONFIG_H

#include <QDialog>

class QCheckBox;
class QComboBox;
class KPluralHandlingSpinBox;
class QDialogButtonBox;
namespace Kleo
{
class FileNameRequester;
}

class KWatchGnuPGConfig : public QDialog
{
    Q_OBJECT
public:
    explicit KWatchGnuPGConfig(QWidget *parent = Q_NULLPTR);
    ~KWatchGnuPGConfig();

    void loadConfig();
    void saveConfig();

Q_SIGNALS:
    void reconfigure();

private Q_SLOTS:
    void slotChanged();
    void slotSave();
    void slotSetHistorySizeUnlimited();

private:
    Kleo::FileNameRequester *mExeED;
    Kleo::FileNameRequester *mSocketED;
    QComboBox *mLogLevelCB;
    KPluralHandlingSpinBox *mLoglenSB;
    QCheckBox *mWordWrapCB;
    QDialogButtonBox *mButtonBox;
};

#endif /* KWATCHGNUPGCONFIG_H */

==> kleopatra_19.12.3.orig.tar.xz: kleopatra-19.12.3/src/kwatchgnupg/kwatchgnupgconfig.h <==
/*
    kwatchgnupgconfig.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2001,2002,2004,2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef KWATCHGNUPGCONFIG_H
#define KWATCHGNUPGCONFIG_H

#include <QDialog>

class QCheckBox;
class QComboBox;
class KPluralHandlingSpinBox;
class QDialogButtonBox;
namespace Kleo
{
class FileNameRequester;
}

class KWatchGnuPGConfig : public QDialog
{
    Q_OBJECT
public:
    explicit KWatchGnuPGConfig(QWidget *parent = nullptr);
    ~KWatchGnuPGConfig();

    void loadConfig();
    void saveConfig();

Q_SIGNALS:
    void reconfigure();

private Q_SLOTS:
    void slotChanged();
    void slotSave();
    void slotSetHistorySizeUnlimited();

private:
    Kleo::FileNameRequester *mExeED;
    Kleo::FileNameRequester *mSocketED;
    QComboBox *mLogLevelCB;
    KPluralHandlingSpinBox *mLoglenSB;
    QCheckBox *mWordWrapCB;
    QDialogButtonBox *mButtonBox;
};

#endif /* KWATCHGNUPGCONFIG_H */
